#
# This file is part of App-Module-Locate
#
# This software is copyright (c) 2011 by Geistteufel <geistteufel@celogeek.fr>.
#
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
#
package App::Module::Locate;

# ABSTRACT: Interface for module locate
use strict;
use warnings;
our $VERSION = '0.2';    # VERSION
1;

__END__

=pod

=head1 NAME

App::Module::Locate - Interface for module locate

=head1 VERSION

version 0.2

=head1 AUTHOR

Geistteufel <geistteufel@celogeek.fr>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Geistteufel <geistteufel@celogeek.fr>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
